/*
  Web client
 
 This sketch connects to a website (http://www.google.com)
 using an Arduino Wiznet Ethernet shield. 
 
 Circuit:
 * Ethernet shield attached to pins 10, 11, 12, 13
 
 created 18 Dec 2009
 by David A. Mellis
 
 */

#include <SPI.h>
#include <Ethernet.h>


//Setup variables
int numberOfSamples = 3000;
//Set Voltage and current input pins
int inPinI = 0;
// Voltage is reduced both by wall xfmr & voltage divider
#define AC_WALL_VOLTAGE        122
#define AC_ADAPTER_VOLTAGE     15.2
// Ratio of the voltage divider in the circuit
#define AC_VOLTAGE_DIV_RATIO   11
// CT: Voltage depends on current, burden resistor, and turns
#define CT_BURDEN_RESISTOR    62
#define CT_TURNS              1900

double ICAL = 0.99;
double PHASECAL = 2.3;

// Initial gueses for ratios, modified by VCAL/ICAL tweaks
double I_RATIO = (long double)CT_TURNS / CT_BURDEN_RESISTOR * 5 / 1024 * ICAL;

//Sample variables
int lastSampleI,sampleI;

//Filter variables
double lastFilteredI, filteredI;
double filterTemp;

//Power calculation variables
double sqI,sumI;

//Useful value variables
double Irms;

// Enter a MAC address and IP address for your controller below.
// The IP address will be dependent on your local network:
byte mac[] = {  0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED };
byte ip[] = { 192,168,1,152 };
byte server[] = { 111,111,101,227 }; // Enter your IP

// Initialize the Ethernet client library
// with the IP address and port of the server 
// that you want to connect to (port 80 is default for HTTP):
Client client(server, 80);

void setup() {
  // start the Ethernet connection:
  Ethernet.begin(mac, ip);
  // start the serial library:
  Serial.begin(9600);
  // give the Ethernet shield a second to initialize:
  delay(1000);
  Serial.println("connecting...");

  // if you get a connection, report back via serial:
  if (client.connect()) {
    Serial.println("connected");
     
  }
  else {
    // kf you didn't get a connection to the server:
    Serial.println("connection failed");
  }
}

void loop()
{
  // if there are incoming bytes available 
  // from the server, read them and print them:
  if (client.connect()) {
    
    
    
    
    for (int n=0; n<numberOfSamples; n++)
{

   //Used for offset removal
   lastSampleI=sampleI;
   
   //Read in voltage and current samples.   
   sampleI = analogRead(inPinI);
   
   //Used for offset removal
   lastFilteredI = filteredI;
  
   //Digital high pass filters to remove 2.5V DC offset.
   filteredI = 0.996 * (lastFilteredI+sampleI-lastSampleI);
   
   //Root-mean-square method current
   //1) square current values
   sqI = filteredI * filteredI;
   //2) sum 
   sumI += sqI;
}

//Calculation of the root of the mean of the voltage and current squared (rms)
//Calibration coeficients applied. 
Irms = (I_RATIO * sqrt(sumI / numberOfSamples)) - 0.09; 


double watt = (230 * Irms);
//Serial.println(Irms);
Serial.println(watt);

sumI = 0;
delay(200);
    
    client.print("GET /emon/api/post?apikey=9888888888888888888&json={power:");
    client.print(watt);
    client.print(",temperature:25.0}");
    client.println();
  }

    // if there are incoming bytes available 
  // from the server, read them and print them:
  if (client.available()) {
    char c = client.read();
    Serial.print(c);
  }
  
    
    client.stop();
    client.flush();
 
}

